Documentation
¶
Index ¶
- func AddBusinessDays(t time.Time, days int) time.Time
- func DaysInMonth(year int, month time.Month) int
- func EndOfDay(t time.Time) time.Time
- func EndOfMonth(t time.Time) time.Time
- func EndOfWeek(t time.Time) time.Time
- func EndOfYear(t time.Time) time.Time
- func IsWeekday(t time.Time) bool
- func IsWeekend(t time.Time) bool
- func StartOfDay(t time.Time) time.Time
- func StartOfMonth(t time.Time) time.Time
- func StartOfWeek(t time.Time) time.Time
- func StartOfYear(t time.Time) time.Time
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddBusinessDays ¶
AddBusinessDays añade o resta días hábiles de lunes a viernes ignorando fines de semana. Preserva la hora local original del instante incluso cuando la aritmética atraviesa una transición de horario de verano (DST), garantizando correctitud temporal.
func DaysInMonth ¶
DaysInMonth calcula la cantidad exacta de días que contiene un mes considerando bisiestos.
func EndOfMonth ¶
EndOfMonth devuelve el último nanosegundo del último día del mes correspondiente.
func StartOfDay ¶
StartOfDay devuelve el inicio del día (00:00:00.000000000) en la zona de la fecha.
func StartOfMonth ¶
StartOfMonth devuelve el primer instante del primer día del mes (00:00:00).
func StartOfWeek ¶
StartOfWeek devuelve el lunes de la semana del instante dado en la zona de la fecha.
Types ¶
This section is empty.